@@ -3,14 +3,15 @@ module Fog
     class Google
       class Mock
         def list_aggregated_instance_groups(_options = {})
+          # :no-coverage:
           Fog::Mock.not_implemented
+          # :no-coverage:
         end
       end
 
       class Real
         def list_aggregated_instance_groups(options = {})
-          @compute.list_aggregated_instance_groups(@project,
-                                                   :filter => options[:filter])
+          @compute.list_aggregated_instance_groups(@project, options)
         end
       end
     end
