@@ -9,7 +9,7 @@ module Fog
         #
         # @return [Array<Fog::DNS::Google::Zone>] List of Managed Zone resources
         def all
-          data = service.list_managed_zones.body["managedZones"] || []
+          data = service.list_managed_zones.managed_zones.to_h || []
           load(data)
         end
 
@@ -19,10 +19,11 @@ module Fog
         # @param [String] name_or_id Managed Zone name or identity
         # @return [Fog::DNS::Google::Zone] Managed Zone resource
         def get(name_or_id)
-          if zone = service.get_managed_zone(name_or_id).body
+          if zone = service.get_managed_zone(name_or_id).to_h
             new(zone)
           end
-        rescue Fog::Errors::NotFound
+        rescue ::Google::Apis::ClientError => e
+          raise e unless e.status_code == 404
           nil
         end
       end
