@@ -7,33 +7,39 @@ module Fog
       # An Operation resource contains information about database instance operations
       # such as create, delete, and restart
       #
-      # @see https://developers.google.com/cloud-sql/docs/admin-api/v1beta3/operations
+      # @see https://cloud.google.com/sql/docs/mysql/admin-api/v1beta4/operations
       class Operation < Fog::Model
-        identity :operation
+        identity :name
 
-        attribute :end_time, :aliases => "endTime"
-        attribute :enqueued_time, :aliases => "enqueuedTime"
-        attribute :error
-        attribute :export_context, :aliases => "exportContext"
-        attribute :import_context, :aliases => "importContext"
-        attribute :instance
-        attribute :kind
+        attribute :kind, :aliases => "kind"
+        attribute :self_link, :aliases => "selfLink"
+        attribute :target_project, :aliases => "targetProject"
+        attribute :target_id, :aliases => "targetId"
+        attribute :target_link, :aliases => "targetLink"
+        attribute :name, :aliases => "name"
         attribute :operation_type, :aliases => "operationType"
+        attribute :status, :aliases => "status"
+        attribute :user, :aliases => "user"
+        attribute :insert_time, :aliases => "insertTime"
         attribute :start_time, :aliases => "startTime"
-        attribute :state
-        attribute :user_email_address, :aliases => "userEmailAddress"
+        attribute :end_time, :aliases => "endTime"
+        attribute :error, :aliases => "error"
+        attribute :import_context, :aliases => "importContext"
+        attribute :export_context, :aliases => "exportContext"
+        attribute :sql_export_options, :aliases => "sqlExportOptions"
+        attribute :csv_export_options, :aliases => "csvExportOptions"
 
-        DONE_STATE    = "DONE"
-        PENDING_STATE = "PENDING"
-        RUNNING_STATE = "RUNNING"
-        UNKNOWN_STATE = "UNKNOWN"
+        DONE_STATE    = "DONE".freeze
+        PENDING_STATE = "PENDING".freeze
+        RUNNING_STATE = "RUNNING".freeze
+        UNKNOWN_STATE = "UNKNOWN".freeze
 
         ##
         # Checks if the instance operation is pending
         #
         # @return [Boolean] True if the operation is pending; False otherwise
         def pending?
-          state == PENDING_STATE
+          status == PENDING_STATE
         end
 
         ##
@@ -41,7 +47,7 @@ module Fog
         #
         # @return [Boolean] True if the operation is done; False otherwise
         def ready?
-          state == DONE_STATE
+          status == DONE_STATE
         end
 
         ##
@@ -51,7 +57,7 @@ module Fog
         def reload
           requires :identity
 
-          data = collection.get(instance, identity)
+          data = collection.get(identity)
           merge_attributes(data.attributes)
           self
         end
