@@ -51,7 +51,7 @@ DATA
             google_headers[key] = value if key[0..6] == "x-goog-"
           end
 
-          google_headers = google_headers.sort { |x, y| x[0] <=> y[0] }
+          google_headers = google_headers.sort_by { |a| a[0] }
           google_headers.each do |key, value|
             canonical_google_headers << "#{key}:#{value}\n"
           end
